/*  ESP32_AsyncWebServer_simple
 * 
 *  Egyszerű mintapélda az AsyncWebServer programkönyvtár használatára.
 *  Itt most csak sima szőveget küldöünk, ezért text/plain a típusjelzés.
 *  Ha HTML kódot küldenénk, akkor text/html típusjelzésre kell váltani.
 *  ESP32 esetén az AsyncWebServer könyvtár az AsyncTCP könyvtárra támaszkodik, 
 *  tehát azt is telepíteni kell, illetve be kell csatolni.
 * 
 *  Tested with Arduino IDE 1.8.19 and ESP32 Arduino Core 2.0.2
 */ 

#include <WiFi.h>
#include <AsyncTCP.h>                  // https://github.com/me-no-dev/AsyncTCP
#include <ESPAsyncWebServer.h>         // https://github.com/me-no-dev/ESPAsyncWebServer
#include "secrets.h"

AsyncWebServer server(80);             // Webszerver objektumpéldány létrehozása

void setup(void) {
  setup_wifi();                        // Csatlakozás a helyi hálózatra
  server.on("/", HTTP_GET, handleRoot);// Visszahívási függvény hozzárendelés
  server.onNotFound(handleNotFound);   // Visszahívási függvény hozzárendelés
  server.begin();                      // Indítjuk a webszervert
}

void loop(void) { }

void handleRoot(AsyncWebServerRequest *request) {                     
  request->send(200, "text/plain", "Hello world!");
}

void handleNotFound(AsyncWebServerRequest *request) { // sikertelen lekérések 
  request->send(404, "text/plain", "404: Not found");
}

void setup_wifi() {
  WiFi.mode(WIFI_STA);
  WiFi.begin(WIFI_SSID, WIFI_PASS);
  Serial.print("Connecting to ");
  Serial.print(WIFI_SSID);
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
  Serial.println();
  Serial.print("Connected! IP address: ");
  Serial.println(WiFi.localIP());
}
