/*  ESP32_WebServer_simple
 * 
 *  Egyszerű mintapélda a WebServer programkönyvtár használatára.
 *  Itt most csak sima szőveget küldünk, ezért text/plain a típusjelzés.
 *  Ha HTML kódot küldenénk, akkor text/html típusjelzésre kell váltani.
 * 
 *  Tested with Arduino IDE 1.8.19 and ESP32 Arduino Core 2.0.2
 */ 

#include <WiFi.h>
#include <WebServer.h>
#include "secrets.h"
WebServer server(80);                   // Webszerver objektumpéldány létrehozása

void setup(void) {
  setup_wifi();                         // Csatlakozás a helyi hálózatra
  server.on("/", handleRoot);           // Visszahívási függvény hozzárendelés
  server.onNotFound(handleNotFound);    // Visszahívási függvény hozzárendelés
  server.begin();                       // Indítjuk a webszervert
}

void loop(void) {
  server.handleClient();                // A kliens kapcsolatok kezelése
}

void handleRoot() {                     // A "/" URI lekérés kiszolgálása
  server.send(200, "text/plain", "Hello world!");
}

void handleNotFound() {                 // A sikertelen lekérések kiszolgálása
  server.send(404, "text/plain", "404: Not found");
}

void setup_wifi() {
  Serial.begin(115200);
  WiFi.mode(WIFI_STA);
  WiFi.begin(WIFI_SSID, WIFI_PASS);
  Serial.print("Connecting to ");
  Serial.print(WIFI_SSID);
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
  Serial.println();
  Serial.print("Connected! IP address: ");
  Serial.println(WiFi.localIP());
}
