/*  ESP32_WebServer_simple
 * 
 *  Egyszerű mintapélda a WiFiServer objektumosztály használatára.
 *  A programban a GPIO34-es analóg bemeneten végzünk mérést és ennek a Voltra
 *  átszámított értékét küldjük el egy HTML állomány formájában. 
 *  A fejlécben jelezzük, hogy 5 s múlva elavul az információ, így a böngésző
 *  automatikusan frissíti a alpot (újra lekéri).
 *
 *  A fülüsleges favicon.ico lekérések elkerülésére vegyük ki a kommentből
 *  az //"<link rel=\"icon\" href=\"data:,\"></head><body>" 
 *  sort a prepareHtmlPage() függvényben!
 *
 *  Tested with Arduino IDE 1.8.19 and ESP32 Arduino Core 2.0.2
 */ 
#include <WiFi.h>
#include "secrets.h"

WiFiServer server(80);

void setup_wifi() {
  WiFi.mode(WIFI_STA);
  WiFi.begin(WIFI_SSID, WIFI_PASS);
  Serial.print("Connecting to ");
  Serial.print(WIFI_SSID);
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
  Serial.println();
  Serial.print("Connected! IP address: ");
  Serial.println(WiFi.localIP());
}

void setup()
{
  Serial.begin(115200);
  Serial.println();
  analogReadResolution(12);             // 12-bit felbontás
  analogSetAttenuation(ADC_11db);       // Méréshatár 0-3,3 V
  setup_wifi();
  server.begin();
  Serial.printf("Web server started, open %s in a web browser\n", WiFi.localIP().toString().c_str());
}


// prepare a web page to be send to a client (web browser)
String prepareHtmlPage()
{
  String htmlPage;
  htmlPage.reserve(1024);               // prevent ram fragmentation
  htmlPage = F("HTTP/1.1 200 OK\r\n"
               "Content-Type: text/html\r\n"
               "Connection: close\r\n"  // the connection will be closed after completion of the response
               "Refresh: 5\r\n"         // refresh the page automatically every 5 sec
               "\r\n"
               "<!DOCTYPE HTML>"
               "<html><head><title>ESP32 WiFiServer</title>"
               //"<link rel=\"icon\" href=\"data:,\"></head><body>"
               "Analog input:  ");
  float v = (analogRead(34)+80)/1239.0f;              
  htmlPage += String(v,3) +" V";
  htmlPage += F("</body></html>"
                "\r\n");
  return htmlPage;
}


void loop()
{
  WiFiClient client = server.available();
  // wait for a client (web browser) to connect
  if (client)
  {
    Serial.println("\n[Client connected]");
    while (client.connected())
    {
      // read line by line what the client (web browser) is requesting
      if (client.available())
      {
        String line = client.readStringUntil('\r');
        Serial.print(line);
        // wait for end of client's request, that is marked with an empty line
        if (line.length() == 1 && line[0] == '\n')
        {
          client.println(prepareHtmlPage());
          break;
        }
      }
    }
    while (client.available()) {
      // but first, let client finish its request
      // that's diplomatic compliance to protocols
      // (and otherwise some clients may complain, like curl)
      // (that is an example, prefer using a proper webserver library)
      client.read();
    }

    // close the connection:
    client.stop();
    Serial.println("[Client disconnected]");
  }
}
